#!/usr/bin/python
#
# Copyright Martin Owens 2010
#
# This script is licensed under the GPLv3
#
"""
Script for modifying a simple svg background with filter effects.
"""
import sys
import os
import random
from xml.dom.minidom import parse
#from xml.dom import Element

# Uper and low bounds on scale and translate transforms.
# A, B, C, D, E, F - ScaleX, 0, 0, ScaleY, TranformX, TranformY
MINIMUM = [ 0.2, None, None, 0.2, 100, 100 ]
MAXIMUM = [ 3, None, None, 3, 1580, 950 ]

# Genetic mutation percentage
MUTATION = 0.01

def mutate(element, emin, emax):
  if emin and emax:
    element = float(element)
    amount = (float(random.randint(int(emin*100), int(emax*100))) / 100) * MUTATION
    if random.choice(('+', '-')) == '+':
      if element + amount <= emax:
        element += amount
    else:
      if element - amount >= emin:
        element -= amount
  return str(element)


if __name__ == '__main__':
  filename = sys.argv[1]

  if os.path.exists(filename):
    xmldom = parse(filename)

    # Split out each section group
    groups = xmldom.getElementsByTagName("g")
    secs = {}
    for group in groups:
       secs[group.getAttribute("id")] = group

    for item in secs['gen'].childNodes:
      if item.nodeType == 1:
        tr = item.getAttribute('transform').split('(')[-1].split(')')[0]
        matrix = tr.split(",")
        for x in range(0, len(matrix)):
          matrix[x] = mutate(matrix[x], MINIMUM[x], MAXIMUM[x])
        tr = ",".join(matrix)
        item.setAttribute('transform', "matrix(%s)" % tr)

    fhs = open(filename, "w")
    fhs.write(xmldom.toxml())
    fhs.close()
  else:
    sys.stderr.write("Unable to update %s: doesn't exist.\n" % filename)

